@@ -1,3 +1,7 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
+
 from .managers.BroadcastManager import Broadcast
 from .managers.CacheManager import Cache
 from .managers.MailManager import Mail
@@ -5,6 +9,15 @@ from .managers.QueueManager import Queue
 from .managers.SessionManager import Session
 from .managers.UploadManager import Upload
 from .environment import env
-from .__version__ import (__title__, __description__, __url__,
-                          __version__, __author__, __author_email__,
-                          __licence__)
+from .__version__ import (
+    __title__,
+    __description__,
+    __url__,
+    __version__,
+    __author__,
+    __author_email__,
+    __licence__,
+    __cookie_cutter_version__
+)
+
+_file_source = 'masonite'
