@@ -11,7 +11,6 @@ class ViewCommand(BaseScaffoldCommand):
     """
 
     scaffold_name = "View"
-    template = '/masonite/snippets/scaffold/view'
-    file_extension = '.html'
-    base_directory = 'resources/templates/'
-    postfix = "View"
+    template = "/masonite/snippets/scaffold/view"
+    file_extension = ".html"
+    base_directory = "resources/templates/"
