@@ -2,9 +2,8 @@ from abc import ABC, abstractmethod
 
 
 class QueueContract(ABC):
-
     @abstractmethod
-    def push(self, *objects, args=(), callback='handle', ran=1, channel=None):
+    def push(self, *objects, args=(), callback="handle", ran=1, channel=None):
         pass
 
     @abstractmethod
