@@ -16,8 +16,15 @@ class WhitenoiseProvider(ServiceProvider):
     def boot(self):
         """Wrap the WSGI server in a whitenoise container."""
         from config import application
-        self.app.bind('WSGI', WhiteNoise(
-            self.app.make('WSGI'), root=config('application.static_root'), autorefresh=application.DEBUG))
 
-        for location, alias in self.app.make('staticfiles').items():
-            self.app.make('WSGI').add_files(location, prefix=alias)
+        self.app.bind(
+            "WSGI",
+            WhiteNoise(
+                self.app.make("WSGI"),
+                root=config("application.static_root"),
+                autorefresh=application.DEBUG,
+            ),
+        )
+
+        for location, alias in self.app.make("staticfiles").items():
+            self.app.make("WSGI").add_files(location, prefix=alias)
