@@ -9,8 +9,11 @@ of this class.
 """
 
 import re
+import cgi
+import json
 from cgi import MiniFieldStorage
 from http import cookies
+from urllib.parse import parse_qs, quote
 
 import tldextract
 from cryptography.fernet import InvalidToken
@@ -22,6 +25,9 @@ from .helpers.Extendable import Extendable
 from .helpers.routes import compile_route_to_regex, query_parse
 from .helpers.status import response_statuses
 from .helpers.time import cookie_expire_time
+from .cookies import CookieJar
+from .headers import HeaderBag, Header
+from .response import Response
 
 
 class Request(Extendable):
@@ -35,8 +41,6 @@ class Request(Extendable):
         have the ability to extend another class at runtime.
     """
 
-    statuses = response_statuses()
-
     def __init__(self, environ=None):
         """Request class constructor.
 
@@ -46,17 +50,18 @@ class Request(Extendable):
         Keyword Arguments:
             environ {dictionary} -- WSGI environ dictionary. (default: {None})
         """
-        self.cookies = []
-        self._headers = {}
+        self.cookie_jar = CookieJar()
+        self.header_bag = HeaderBag()
         self.url_params = {}
         self.redirect_url = False
         self.redirect_route = False
         self.user_model = None
         self.subdomain = None
         self._activate_subdomains = False
-        self._status = None
         self.request_variables = {}
         self._test_user = False
+        self.raw_input = None
+        self.query_params = {}
 
         if environ:
             self.load_environ(environ)
@@ -64,7 +69,7 @@ class Request(Extendable):
         self.encryption_key = False
         self.container = None
 
-    def input(self, name, default=False, clean=False):
+    def input(self, name, default=False, clean=False, quote=True):
         """Get a specific input value.
 
         Arguments:
@@ -78,15 +83,53 @@ class Request(Extendable):
         Returns:
             string
         """
-        if '.' in name and isinstance(self.request_variables.get(name.split('.')[0]), dict):
-            value = DictDot().dot(name, self.request_variables)
-            if value:
-                return value
+        name = str(name)
 
-        elif '.' in name:
+        if "." in name and isinstance(
+            self.request_variables.get(name.split(".")[0]), dict
+        ):
+            return clean_request_input(
+                DictDot().dot(name, self.request_variables, default=default),
+                clean=clean,
+            )
+
+        elif "." in name:
             name = dot(name, "{1}[{.}]")
 
-        return clean_request_input(self.request_variables.get(name, default), clean=clean)
+        return clean_request_input(
+            self.request_variables.get(name, default), clean=clean, quote=quote
+        )
+
+    def query(self, name, default=None, multi=False):
+        """Get a specific query string value.
+
+        Arguments:
+            name {string} -- Key of the input data
+
+        Keyword Arguments:
+            default {any} -- Default value if input does not exist (default: {None})
+            multi {bool} -- Whether to return all values of a multi value query string param
+                            ie. quuery_param=one&query_param=two (default: {False})
+
+        Returns:
+            any
+        """
+        try:
+            value = self.query_params[name]
+        except KeyError:
+            return default
+
+        if not multi and value:
+            return value[0]
+        return value
+
+    def all_query(self):
+        """Get all query string values
+
+        Returns:
+            any
+        """
+        return self.query_params
 
     def is_post(self):
         """Check if the current request is a POST request.
@@ -94,7 +137,7 @@ class Request(Extendable):
         Returns:
             bool
         """
-        if self.environ['REQUEST_METHOD'] == 'POST':
+        if self.environ["REQUEST_METHOD"] == "POST":
             return True
 
         return False
@@ -105,7 +148,7 @@ class Request(Extendable):
         Returns:
             bool
         """
-        if not self.environ['REQUEST_METHOD'] == 'GET':
+        if not self.environ["REQUEST_METHOD"] == "GET":
             return True
 
         return False
@@ -116,8 +159,8 @@ class Request(Extendable):
         Returns:
             bool
         """
-        if self.has('__method'):
-            self.environ['REQUEST_METHOD'] = self.input('__method')
+        if self.has("__method"):
+            self.environ["REQUEST_METHOD"] = self.input("__method")
             return True
 
         return False
@@ -134,7 +177,7 @@ class Request(Extendable):
         self.encryption_key = key
         return self
 
-    def all(self, internal_variables=True, clean=True):
+    def all(self, internal_variables=True, clean=True, quote=True):
         """Get all the input data.
 
         Keyword Arguments:
@@ -146,14 +189,18 @@ class Request(Extendable):
         Returns:
             dict
         """
+
+        if isinstance(self.raw_input, list):
+            return self.raw_input
+
         if not internal_variables:
             without_internals = {}
             for key, value in self.request_variables.items():
-                if not key.startswith('__'):
+                if not key.startswith("__"):
                     without_internals.update({key: value})
-            return clean_request_input(without_internals, clean=clean)
+            return clean_request_input(without_internals, clean=clean, quote=quote)
 
-        return clean_request_input(self.request_variables, clean=clean)
+        return clean_request_input(self.request_variables, clean=clean, quote=quote)
 
     def only(self, *names):
         """Return the specified request variables in a dictionary.
@@ -204,16 +251,61 @@ class Request(Extendable):
             self
         """
         self.environ = environ
-        self.method = environ['REQUEST_METHOD']
-        self.path = environ['PATH_INFO']
-        if 'QUERY_STRING' in environ:
-            self._set_standardized_request_variables(environ['QUERY_STRING'])
+        self.header_bag.load(environ)
+        self.method = environ["REQUEST_METHOD"]
+        self.path = environ["PATH_INFO"]
+        self.request_variables = {}
+        self.raw_input = None
 
-        if self.has('__method'):
+        if "QUERY_STRING" in environ and environ["QUERY_STRING"]:
+            self.query_params = parse_qs(environ["QUERY_STRING"])
+
+        if self.is_not_get_request():
+            environ["POST_DATA"] = self.get_post_params()
+
+        if "POST_DATA" in environ:
+            self._set_standardized_request_variables(environ["POST_DATA"])
+        elif "QUERY_STRING" in environ and environ["QUERY_STRING"]:
+            self._set_standardized_request_variables(environ["QUERY_STRING"])
+
+        if "HTTP_COOKIE" in environ:
+            self.cookie_jar.load(environ["HTTP_COOKIE"])
+
+        if self.has("__method"):
             self.__set_request_method()
 
         return self
 
+    def get_post_params(self):
+        """Return the correct input.
+
+        Returns:
+            dict -- Dictionary of post parameters.
+        """
+        fields = None
+        if (
+            "CONTENT_TYPE" in self.environ
+            and "application/json" in self.environ["CONTENT_TYPE"].lower()
+        ):
+            try:
+                request_body_size = int(self.environ.get("CONTENT_LENGTH", 0))
+            except ValueError:
+                request_body_size = 0
+
+            request_body = self.environ["wsgi.input"].read(request_body_size)
+
+            if isinstance(request_body, bytes):
+                request_body = request_body.decode("utf-8")
+
+            return json.loads(request_body or "{}")
+        else:
+            fields = cgi.FieldStorage(
+                fp=self.environ["wsgi.input"],
+                environ=self.environ,
+                keep_blank_values=1,
+            )
+            return fields
+
     def _set_standardized_request_variables(self, variables):
         """The input data is not perfect so we have to standardize it into a dictionary.
 
@@ -224,11 +316,14 @@ class Request(Extendable):
         if isinstance(variables, str):
             variables = query_parse(variables)
 
+        self.raw_input = variables
+        if isinstance(variables, list):
+            variables = {str(i): v for i, v in enumerate(variables)}
+
         try:
-            self.request_variables = {}
             for name in variables.keys():
                 value = self._get_standardized_value(variables[name])
-                self.request_variables[name.replace('[]', '')] = value
+                self.request_variables[name.replace("[]", "")] = value
             return
         except TypeError:
             pass
@@ -292,6 +387,107 @@ class Request(Extendable):
         """
         return all((arg in self.request_variables) for arg in args)
 
+    def scheme(self):
+        """Get the current request url scheme
+
+        Returns:
+            string -- the scheme used for the request (http|https)
+        """
+        return self.environ["wsgi.url_scheme"]
+
+    def referrer(self):
+        """Gets the URL of the request that the current URL came from.
+
+        Returns:
+            string -- Returns the previous referring URL.
+        """
+
+        return self.environ.get("HTTP_REFERER")
+
+    def host(self):
+        """Get the server's hostname for the current request.
+
+        Returns:
+            string -- the hostname
+        """
+        host = self.environ.get("HTTP_HOST")
+        if not host:
+            host = self.environ["SERVER_NAME"]
+        return host.split(":", 1)[0]
+
+    def port(self):
+        """Get the server's port number for the current request.
+
+        Returns:
+            string -- the server's port number.
+        """
+        return self.environ["SERVER_PORT"]
+
+    def full_path(self, quoted=True):
+        """Get the path part of the current request url. (including the application path).
+
+        Args:
+            quoted {bool} -- whether to escape special chars (default: {True}).
+
+        Returns:
+            string -- the path of the url
+        """
+        url = self.environ.get("SCRIPT_NAME", "") + self.environ.get("PATH_INFO", "")
+        if quoted:
+            url = quote(url)
+        return url
+
+    def url(self, include_standard_port=False):
+        """Get the url of the current request including the scheme://host:port/path.
+
+        Args:
+            include_standard_port {bool} -- whether to include the port
+                when the request uses the standard http(s) port (default: {False}).
+
+        Returns:
+            string -- the requested url.
+        """
+        scheme = self.scheme()
+        host = self.host()
+        port = self.port()
+        path = self.full_path()
+        if (
+            include_standard_port
+            or (scheme == "https" and port != "443")
+            or (scheme == "http" and port != "80")
+        ):
+            port_part = ":{}".format(port)
+        else:
+            port_part = ""
+        return "{}://{}{}{}".format(scheme, host, port_part, path)
+
+    def full_url(self, include_standard_port=False):
+        """Get the full url including query string of the current request.
+            example:
+             scheme://host:port/path?query-string
+
+        Args:
+            include_standard_port {bool} -- whether to include the port
+                when the request uses the standard http(s) port (default: {False}).
+
+        Returns:
+            string -- The full request url
+        """
+        url = self.url(include_standard_port=include_standard_port)
+        query_string = self.query_string()
+        if query_string:
+            return "{}?{}".format(url, query_string)
+        else:
+            return url
+
+    def query_string(self):
+        """Get the raw query string of the current request url.
+
+        Returns:
+            string -- The query-string of the request
+        """
+        return self.environ.get("QUERY_STRING", "")
+
     def status(self, status):
         """Set the HTTP status code.
 
@@ -301,29 +497,10 @@ class Request(Extendable):
         Returns:
             self
         """
-        if isinstance(status, str):
-            self.app().bind('StatusCode', status)
-        elif isinstance(status, int):
-            try:
-                text_status = self.statuses[status]
-            except KeyError:
-                raise InvalidHTTPStatusCode
-            self.app().bind('StatusCode', text_status)
-        return self
-
-    def get_status_code(self):
-        """Return the current request status code.
-
-        Returns:
-            string -- Returns the status code (404 Not Found, 200 OK, etc)
-        """
-        return self.app().make('StatusCode')
-
-    def is_status(self, code):
-        return self._get_status_code_by_value(self.get_status_code()) == code
+        return self.app().make(Response).status(status)
 
     def route_exists(self, url):
-        web_routes = self.container.make('WebRoutes')
+        web_routes = self.container.make("WebRoutes")
 
         for route in web_routes:
             if route.route_url == url:
@@ -331,25 +508,15 @@ class Request(Extendable):
 
         return False
 
-    def _get_status_code_by_value(self, value):
-        for key, status in self.statuses.items():
-            if status == value:
-                return key
-
-        return None
-
-    def get_status(self):
-        return self._get_status_code_by_value(self.get_status_code())
-
     def get_request_method(self):
         """Get the current request method.
 
         Returns:
             string -- returns GET, POST, PUT, etc
         """
-        return self.environ['REQUEST_METHOD']
+        return self.environ["REQUEST_METHOD"]
 
-    def header(self, key, value=None, http_prefix=None):
+    def header(self, key, value=None):
         """Set or gets a header depending on if "value" is passed in or not.
 
         Arguments:
@@ -358,7 +525,6 @@ class Request(Extendable):
 
         Keyword Arguments:
             value {string} -- The value you want to set (default: {None})
-            http_prefix {bool} -- Whether it should have `HTTP_` prefixed to the value being set. (default: {True})
 
         Returns:
             string|None|True -- Either return the value if getting a header,
@@ -366,31 +532,25 @@ class Request(Extendable):
         """
         if isinstance(key, dict):
             for dic_key, dic_value in key.items():
-                self._set_header(dic_key, dic_value, http_prefix)
+                self._set_header(dic_key, dic_value)
             return
 
         # Get Headers
         if value is None:
-            if key in self.environ:
-                return self.environ[key]
-            elif key.upper().replace('-', '_') in self.environ:
-                return self.environ[key.upper().replace('-', '_')]
-            else:
-                return ''
+            header = self.header_bag.get(key)
+            if header:
+                return header.value
+            return ""
 
-        self._set_header(key, value, http_prefix)
+        self._set_header(key, value)
 
-    def _set_header(self, key, value, http_prefix):
+    def _set_header(self, key, value):
         # Set Headers
-        if http_prefix:
-            self.environ['HTTP_{0}'.format(key)] = str(value)
-            self._headers.update({'HTTP_{0}'.format(key): str(value)})
-        else:
-            self.environ[key] = str(value)
-            self._headers.update({key: str(value)})
+
+        self.header_bag.add(Header(key, value))
 
     def has_raw_header(self, key):
-        return key in self._headers
+        return key in self.header_bag
 
     def get_headers(self):
         """Return all current headers to be set.
@@ -399,7 +559,7 @@ class Request(Extendable):
             list -- List containing a tuple of headers.
         """
 
-        return self._compile_headers_to_tuple() + self.get_cookies()
+        return self._compile_headers_to_tuple() + self.cookie_jar.render_response()
 
     def _compile_headers_to_tuple(self):
         """Compiles the current headers to a list of tuples.
@@ -408,11 +568,7 @@ class Request(Extendable):
             list -- A list of tuples.
         """
 
-        headers = []
-        for key, value in self._headers.items():
-            headers.append((key, value))
-
-        return headers
+        return self.header_bag.render()
 
     def reset_headers(self):
         """Reset all headers being set.
@@ -423,7 +579,7 @@ class Request(Extendable):
         Returns:
             None
         """
-        self._headers = {}
+        self.header_bag = HeaderBag()
 
     def get_and_reset_headers(self):
         """Gets the headers but resets at the same time.
@@ -437,7 +593,7 @@ class Request(Extendable):
         headers = self.get_headers()
         self.reset_headers()
         self.url_params = {}
-        self.cookies = []
+        self.cookie_jar = CookieJar()
         return headers
 
     def set_params(self, params):
@@ -471,8 +627,16 @@ class Request(Extendable):
             return self.url_params.get(parameter)
         return False
 
-    def cookie(self, key, value, encrypt=True,
-               http_only="HttpOnly;", path='/', expires=''):
+    def cookie(
+        self,
+        key,
+        value,
+        encrypt=True,
+        http_only="HttpOnly;",
+        path="/",
+        expires=None,
+        secure=False,
+    ):
         """Set a cookie in the browser.
 
         Arguments:
@@ -490,21 +654,28 @@ class Request(Extendable):
         Returns:
             self
         """
+
+        if self.environ.get("SECURE_COOKIES") == "True":
+            secure = True
+
         if encrypt:
             value = Sign(self.encryption_key).sign(value)
         else:
             value = value
 
         if expires:
-            expires = "Expires={0};".format(cookie_expire_time(expires))
+            expires = cookie_expire_time(expires)
 
-        if not http_only:
-            http_only = ""
+        self.cookie_jar.add(
+            key,
+            value,
+            expires=expires,
+            http_only=http_only,
+            secure=secure,
+            path=path,
+            timezone="GMT",
+        )
 
-        self.append_cookie('{0}={1};{2} {3}Path={4}'.format(key, value, expires, http_only, path))
-        self.cookies.append(
-            ('Set-Cookie', '{0}={1};{2} {3}Path={4}'.format(
-                key, value, expires, http_only, path)))
         return self
 
     def get_cookies(self):
@@ -513,15 +684,10 @@ class Request(Extendable):
         Returns:
             dict -- Returns all the cookies.
         """
-        return self.cookies
+        return self.cookie_jar
 
     def get_raw_cookie(self, provided_cookie):
-        if 'HTTP_COOKIE' in self.environ:
-            grab_cookie = cookies.SimpleCookie(self.environ['HTTP_COOKIE'])
-            if provided_cookie in grab_cookie:
-                return grab_cookie[provided_cookie]
-
-        return None
+        return self.cookie_jar.get(provided_cookie)
 
     def get_cookie(self, provided_cookie, decrypt=True):
         """Retrieve a specific cookie from the browser.
@@ -537,20 +703,18 @@ class Request(Extendable):
         Returns:
             string|None -- Returns None if the cookie does not exist.
         """
-        if 'HTTP_COOKIE' in self.environ:
-            grab_cookie = cookies.SimpleCookie(self.environ['HTTP_COOKIE'])
-
-            if provided_cookie in grab_cookie:
-                if decrypt:
-                    try:
-                        return Sign(self.encryption_key).unsign(
-                            grab_cookie[provided_cookie].value)
-                    except InvalidToken:
-                        self.delete_cookie(provided_cookie)
-                        return None
-
-                return grab_cookie[provided_cookie].value
-        return None
+        if decrypt:
+            try:
+                return Sign(self.encryption_key).unsign(
+                    self.cookie_jar.get(provided_cookie).value
+                )
+            except InvalidToken:
+                self.delete_cookie(provided_cookie)
+                return None
+            except AttributeError:
+                pass
+        if self.cookie_jar.exists(provided_cookie):
+            return self.cookie_jar.get(provided_cookie).value
 
     def append_cookie(self, value):
         """Append cookie to the string or create a new string.
@@ -563,10 +727,10 @@ class Request(Extendable):
             key {string} -- Name of cookie to be stored
             value {string} -- Value of cookie to be stored
         """
-        if 'HTTP_COOKIE' in self.environ and self.environ['HTTP_COOKIE']:
-            self.environ['HTTP_COOKIE'] += ';{}'.format(value)
+        if "HTTP_COOKIE" in self.environ and self.environ["HTTP_COOKIE"]:
+            self.environ["HTTP_COOKIE"] += ";{}".format(value)
         else:
-            self.environ['HTTP_COOKIE'] = '{}'.format(value)
+            self.environ["HTTP_COOKIE"] = "{}".format(value)
 
     def delete_cookie(self, key):
         """Delete cookie.
@@ -577,24 +741,9 @@ class Request(Extendable):
         Returns:
             bool -- Whether or not the cookie was successfully deleted.
         """
-        for index, cookie in enumerate(self.cookies):
-            if cookie[1].startswith(key + '='):
-                del self.cookies[index]
+        self.cookie_jar.delete(key)
 
-        self.cookie(key, '', expires='expired')
-
-        if 'HTTP_COOKIE' in self.environ and self.environ['HTTP_COOKIE']:
-
-            request_cookies = self.environ['HTTP_COOKIE'].split(';')
-            for index, cookie in enumerate(request_cookies):
-                if cookie.startswith(key):
-                    # remove that cookie
-                    del request_cookies[index]
-
-            # put string back together
-            self.environ['HTTP_COOKIE'] = ';'.join(request_cookies)
-            return True
-        return False
+        self.cookie(key, "", expires="expired")
 
     def set_user(self, user_model):
         """Load the user into the class.
@@ -614,8 +763,7 @@ class Request(Extendable):
         return self
 
     def reset_user(self):
-        """Resets the user back to none
-        """
+        """Resets the user back to none"""
         self.user_model = None
 
     def user(self):
@@ -624,9 +772,13 @@ class Request(Extendable):
         Returns:
             app.User.User|None -- Returns None if the user is not loaded or logged in.
         """
+        # if self.app().has("User") and self.app().make("User"):
+        #     return self.app().make("User")
         return self.user_model
 
-    def redirect(self, route=None, params={}, name=None, controller=None, status=302):
+    def redirect(
+        self, route=None, params={}, name=None, controller=None, url=None, status=302
+    ):
         """Redirect the user based on the route specified.
 
         Arguments:
@@ -646,6 +798,8 @@ class Request(Extendable):
             self.redirect_url = self.compile_route_to_url(route, params)
         elif controller:
             self.redirect_url = self.url_from_controller(controller, params)
+        elif url:
+            self.redirect_url = url
 
         self.status(status)
         return self
@@ -684,13 +838,15 @@ class Request(Extendable):
             string|None -- Returns None if the route was not found or returns the
                            compiled URI.
         """
-        web_routes = self.container.make('WebRoutes')
+        web_routes = self.container.make("WebRoutes")
 
         for route in web_routes:
             if route.named_route == name:
                 return self.compile_route_to_url(route.route_url, params)
 
-        raise RouteException("Could not find the route with the name of '{}'".format(name))
+        raise RouteException(
+            "Could not find the route with the name of '{}'".format(name)
+        )
 
     def _get_route_from_controller(self, controller):
         """Get the route using the controller.
@@ -705,17 +861,21 @@ class Request(Extendable):
         Returns:
             masonite.routes.Route|None -- Returns None if the route could not be found.
         """
-        web_routes = self.container.make('WebRoutes')
+        web_routes = self.container.make("WebRoutes")
 
         if not isinstance(controller, str):
             module_location = controller.__module__
-            controller = controller.__qualname__.split('.')
+            controller = controller.__qualname__.split(".")
         else:
-            module_location = 'app.http.controllers'
-            controller = controller.split('@')
+            module_location = "app.http.controllers"
+            controller = controller.split("@")
 
         for route in web_routes:
-            if route.controller.__name__ == controller[0] and route.controller_method == controller[1] and route.module_location == module_location:
+            if (
+                route.controller.__name__ == controller[0]
+                and route.controller_method == controller[1]
+                and route.module_location == module_location
+            ):
                 return route
 
     def url_from_controller(self, controller, params={}):
@@ -732,7 +892,9 @@ class Request(Extendable):
         Returns:
             masonite.routes.Route|None -- Returns None if the route could not be found.
         """
-        return self.compile_route_to_url(self._get_route_from_controller(controller).route_url, params)
+        return self.compile_route_to_url(
+            self._get_route_from_controller(controller).route_url, params
+        )
 
     def route(self, name, params={}, full=False):
         """Get a route URI by its name.
@@ -750,6 +912,7 @@ class Request(Extendable):
             masonite.routes.Route|None -- Returns None if the route cannot be found.
         """
         from config import application
+
         if full:
             route = application.URL + self._get_named_route(name, params)
         else:
@@ -761,7 +924,9 @@ class Request(Extendable):
                 route = self._get_named_route(name, params)
 
         if not route:
-            raise RouteException("Route with the name of '{}' was not found.".format(name))
+            raise RouteException(
+                "Route with the name of '{}' was not found.".format(name)
+            )
 
         return route
 
@@ -777,7 +942,16 @@ class Request(Extendable):
         raise AttributeError("class 'Request' has no attribute {}".format(key))
 
     def with_errors(self, errors):
-        self.session.flash('errors', errors)
+        """Easily attach errors message to session request."""
+        return self.with_flash("error", errors)
+
+    def with_success(self, success):
+        """Easily attach success message to session request."""
+        return self.with_flash("success", success)
+
+    def with_flash(self, key, value):
+        """Easily attach data to session request."""
+        self.session.flash(key, value)
         return self
 
     def reset_redirections(self):
@@ -796,16 +970,30 @@ class Request(Extendable):
         """
         self.with_input()
 
-        redirect_url = self.input('__back')
-        if not redirect_url and default:
-            return self.redirect(default)
-        elif not redirect_url and not default:
-            return self.redirect(self.path)  # Some global default?
+        redirect_url = self.input("__back")
 
-        return self.redirect(redirect_url)
+        if not redirect_url and default:
+            return self.redirect(url=default)
+        elif not redirect_url and not default:
+            return self.redirect(url=self.path)
+
+        return self.redirect(url=redirect_url)
+
+    def then_back(self):
+        self.session.set("__intend", self.path)
+        return self
+
+    def redirect_intended(self, default=None):
+        if self.session.get("__intend"):
+            self.redirect(self.session.get("__intend"))
+            self.session.delete("__intend")
+        else:
+            self.redirect(default)
+
+        return self
 
     def flash_inputs_to_session(self):
-        if not hasattr(self, 'session'):
+        if not hasattr(self, "session"):
             return
 
         for key, value in self.all().items():
@@ -844,7 +1032,7 @@ class Request(Extendable):
             if re.match(compile_route_to_regex(route), self.path):
                 return show
 
-            return ''
+            return ""
 
         return re.match(compile_route_to_regex(route), self.path)
 
@@ -867,44 +1055,44 @@ class Request(Extendable):
             return route
 
         # Split the url into a list
-        split_url = route.split('/')
+        split_url = route.split("/")
 
         # Start beginning of the new compiled url
-        compiled_url = '/'
+        compiled_url = "/"
 
         # Iterate over the list
         for url in split_url:
             if url:
                 # if the url contains a parameter variable like @id:int
-                if '@' in url:
-                    url = url.replace('@', '').split(':')[0]
+                if "@" in url:
+                    url = url.replace("@", "").split(":")[0]
                     if isinstance(params, dict):
-                        compiled_url += str(params[url]) + '/'
+                        compiled_url += str(params[url]) + "/"
                     elif isinstance(params, list):
-                        compiled_url += str(params.pop(0)) + '/'
-                elif '?' in url:
-                    url = url.replace('?', '').split(':')[0]
+                        compiled_url += str(params.pop(0)) + "/"
+                elif "?" in url:
+                    url = url.replace("?", "").split(":")[0]
                     if isinstance(params, dict):
-                        compiled_url += str(params.get(url, '/')) + '/'
+                        compiled_url += str(params.get(url, "/")) + "/"
                     elif isinstance(params, list):
-                        compiled_url += str(params.pop(0)) + '/'
+                        compiled_url += str(params.pop(0)) + "/"
                 else:
-                    compiled_url += url + '/'
+                    compiled_url += url + "/"
 
-        compiled_url = compiled_url.replace('//', '')
+        compiled_url = compiled_url.replace("//", "")
         # The loop isn't perfect and may have an unwanted trailing slash
-        if compiled_url.endswith('/') and not route.endswith('/'):
+        if compiled_url.endswith("/") and not route.endswith("/"):
             compiled_url = compiled_url[:-1]
 
         # The loop isn't perfect and may have 2 slashes next to eachother
-        if '//' in compiled_url:
-            compiled_url = compiled_url.replace('//', '/')
+        if "//" in compiled_url:
+            compiled_url = compiled_url.replace("//", "/")
 
         return compiled_url
 
     def activate_subdomains(self):
         """Activate subdomains abilities."""
-        self._activate_subdomains = True
+        self.app().bind("Subdomains", True)
 
     def has_subdomain(self):
         """Check if the current URI has a subdomain.
@@ -912,12 +1100,12 @@ class Request(Extendable):
         Returns:
             bool
         """
-        if self._activate_subdomains:
-            url = tldextract.extract(self.environ['HTTP_HOST'])
+        if self.app().has("Subdomains") and self.app().make("Subdomains"):
+            url = tldextract.extract(self.environ["HTTP_HOST"])
 
             if url.subdomain:
                 self.subdomain = url.subdomain
-                self.url_params.update({'subdomain': self.subdomain})
+                self.url_params.update({"subdomain": self.subdomain})
                 return True
 
         return False
@@ -949,5 +1137,5 @@ class Request(Extendable):
                 del self.request_variables[key]
 
     def validate(self, *rules):
-        validator = self.app().make('Validator')
+        validator = self.app().make("Validator")
         return validator.validate(self.request_variables, *rules)
